@@ -7,9 +7,9 @@ except ImportError:
 
 from ikazuchi.core.handler.rstfile import reSTParser, reSTApiCaller
 from ikazuchi.core.translator import TRANSLATE_API
+from ikazuchi.vim.utils import (to_encode, get_vim_variables,
+                                get_apikey, get_translate_method)
 from os.path import splitext
-from utils import (to_unicode, to_encode, get_vim_variables,
-                   get_apikey, get_translate_method)
 
 def get_target_lines(start, end, enc):
     _lines = vim.current.buffer[start:end]
@@ -21,7 +21,8 @@ def get_target_range():
     start = vim.current.range.start
     end = vim.current.range.end + 1
     if cur_row == end and (start + 1) == end:
-        while vim.current.buffer[end:end + 1] != [""]:
+        max_row = len(vim.current.buffer)
+        while vim.current.buffer[end:end + 1] != [""] and end < max_row:
             end += 1
     return start, end
 
@@ -59,7 +60,7 @@ def main():
         if ext == "rst":
             comment_out_original_lines()
     except Exception as err:
-        print "Got error: {0}".format(err.message)
+        print "Got error: {0}".format(err)
 
 if __name__ == "__main__":
     main()
